pub enum ApplyPatchError {
ParseError(ParseError),
IoError(IoError),
ComputeReplacements(String),
ImplicitInvocation,
}Variants
ParseError(ParseError)
IoError(IoError)
ComputeReplacements(String)
Error that occurs while computing replacements when applying patch chunks
ImplicitInvocation
A raw patch body was provided without an explicit apply_patch invocation.